@@ -5,7 +5,8 @@ from netbox_storage.api.views import (
     DriveViewSet,
     FilesystemViewSet,
     LinuxVolumeViewSet,
-    LinuxVolumeDriveViewSet,
+    PartitionViewSet,
+    PhysicalVolumeViewSet,
 )
 
 router = NetBoxRouter()
@@ -14,6 +15,7 @@ router.APIRootView = NetboxStorageRootView
 router.register("drive", DriveViewSet)
 router.register("filesystem", FilesystemViewSet)
 router.register("linuxvolume", LinuxVolumeViewSet)
-router.register("linuxvolumedrive", LinuxVolumeDriveViewSet)
+router.register("partition", PartitionViewSet)
+router.register("physicalvolume", PhysicalVolumeViewSet)
 
 urlpatterns = router.urls
