@@ -95,6 +95,9 @@ class Partition(NetBoxModel):
     def docs_url(self):
         return f'https://confluence.ti8m.ch/docs/models/partition/'
 
+    def physicalvolumes_count(self):
+        return PhysicalVolume.objects.filter(partition=self).count()
+
 
 class PhysicalVolume(NetBoxModel):
     partition = models.ForeignKey(
