@@ -43,7 +43,7 @@ from netbox_storage.views import (
     PhysicalVolumeBulkEditView,
     PhysicalVolumeBulkDeleteView,
     PhysicalVolumeView,
-    PhysicalVolumeDeleteView, DrivePartitionListView,
+    PhysicalVolumeDeleteView, DrivePartitionListView, PartitionPhysicalVolumeListView,
 )
 
 app_name = "netbox_storage"
@@ -118,6 +118,9 @@ urlpatterns = [
         name="partition_changelog",
         kwargs={"model": Partition},
     ),
+    #path("partition/<int:pk>/physicalvolume/",
+    #     PartitionPhysicalVolumeListView.as_view(),
+    #     name="partition_physicalvolumes"),
     #
     # PhysicalVolume urls
     #
